Logger class

A simple logger class for outputting messages to the console.

This class provides static methods for logging different types of messages with appropriate emojis.

Constructors

Logger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

info(String msg) → void
Logs an informational message.
success(String msg) → void
Logs a success message.
warn(String msg) → void
Logs a warning message.